src/inc/vGfx.h 1.15

1.15 2009/08/19 22:28:36 angie
Added option to mgSaveToGif and its call stack, to use GIF's Graphic Control Extension to make memgfx's background color (0) transparent. Also corrected terminology for PNG in .h files: useAlpha -> useTransparency.
Index: src/inc/vGfx.h
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/inc/vGfx.h,v
retrieving revision 1.14
retrieving revision 1.15
diff -b -B -U 4 -r1.14 -r1.15
--- src/inc/vGfx.h	5 Aug 2009 23:34:31 -0000	1.14
+++ src/inc/vGfx.h	19 Aug 2009 22:28:36 -0000	1.15
@@ -89,15 +89,17 @@
     int (*getFontStringWidth)(void *v, void *font, char *string);
     /* How wide is a string? */
     };
 
-struct vGfx *vgOpenGif(int width, int height, char *fileName);
-/* Open up something that we'll write out as a gif 
- * someday. */
+struct vGfx *vgOpenGif(int width, int height, char *fileName, boolean useTransparency);
+/* Open up something that will write out a GIF file upon vgClose.
+ * If useTransparency, then the first color in memgfx's colormap/palette is
+ * assumed to be the image background color, and pixels of that color
+ * are made transparent. */
 
-struct vGfx *vgOpenPng(int width, int height, char *fileName, boolean useAlpha);
+struct vGfx *vgOpenPng(int width, int height, char *fileName, boolean useTransparency);
 /* Open up something that will write out a PNG file upon vgClose.  
  * If useAlpha, then the first color in memgfx's colormap/palette is
  * assumed to be the image background color, and pixels of that color
  * are made transparent. */
 
@@ -89,15 +89,17 @@
 /* Open up something that will write out a PNG file upon vgClose.  
- * If useAlpha, then the first color in memgfx's colormap/palette is
+ * If useTransparency, then the first color in memgfx's colormap/palette is
  * assumed to be the image background color, and pixels of that color
  * are made transparent. */
 struct vGfx *vgOpenPostScript(int width, int height, char *fileName);